'use strict';

var ezScrollbarCore = require('@niku/ez-scrollbar-core');
var react = require('react');
var jsxRuntime = require('react/jsx-runtime');

var __defProp = Object.defineProperty;
var __name = (target, value) => __defProp(target, "name", { value, configurable: true });
var HorizontalScrollBar = /* @__PURE__ */ __name(({
  container,
  autoHide = true,
  modifier,
  updateStyle,
  style,
  ...props
}) => {
  const scrollBarRef = react.useRef(null);
  const [scrollBarInstance] = react.useState(
    () => new ezScrollbarCore.HorizontalScrollBarInstance({
      container,
      scrollBar: scrollBarRef.current || void 0,
      modifier,
      autoHide,
      updateStyle
    })
  );
  react.useEffect(() => {
    scrollBarInstance.updateOptions({
      container,
      scrollBar: scrollBarRef.current || void 0,
      modifier,
      autoHide,
      updateStyle
    });
    return () => {
      scrollBarInstance.unmount();
    };
  }, [container, autoHide, modifier, updateStyle]);
  return /* @__PURE__ */ jsxRuntime.jsx("div", { ...props, ref: scrollBarRef });
}, "HorizontalScrollBar");
var VerticalScrollBar = /* @__PURE__ */ __name(({
  container,
  modifier,
  autoHide = true,
  updateStyle,
  style,
  ...props
}) => {
  const scrollBarRef = react.useRef(null);
  const [scrollBarInstance] = react.useState(
    () => new ezScrollbarCore.VerticalScrollBarInstance({
      container,
      scrollBar: scrollBarRef.current || void 0,
      modifier,
      autoHide,
      updateStyle
    })
  );
  react.useEffect(() => {
    scrollBarInstance.updateOptions({
      container,
      scrollBar: scrollBarRef.current || void 0,
      modifier,
      autoHide,
      updateStyle
    });
    return () => {
      scrollBarInstance.unmount();
    };
  }, [container, autoHide, modifier, updateStyle]);
  return /* @__PURE__ */ jsxRuntime.jsx("div", { ...props, ref: scrollBarRef });
}, "VerticalScrollBar");
var ScrollBar = /* @__PURE__ */ __name(({
  children,
  vertical = true,
  horizontal = true,
  ...props
}) => {
  const [container, setContainer] = react.useState();
  return /* @__PURE__ */ jsxRuntime.jsxs(
    "div",
    {
      ...props,
      ref: (el) => {
        if (container !== el) {
          setContainer(el || void 0);
        }
      },
      children: [
        children,
        horizontal ? /* @__PURE__ */ jsxRuntime.jsx(
          HorizontalScrollBar,
          {
            container,
            ...typeof horizontal === "object" ? horizontal : {}
          }
        ) : null,
        vertical ? /* @__PURE__ */ jsxRuntime.jsx(
          VerticalScrollBar,
          {
            container,
            ...typeof vertical === "object" ? vertical : {}
          }
        ) : null
      ]
    }
  );
}, "ScrollBar");

exports.HorizontalScrollBar = HorizontalScrollBar;
exports.ScrollBar = ScrollBar;
exports.VerticalScrollBar = VerticalScrollBar;
