import { HorizontalScrollBarInstance, VerticalScrollBarInstance } from '@niku/ez-scrollbar-core';
import { useRef, useState, useEffect } from 'react';
import { jsx, jsxs } from 'react/jsx-runtime';

var __defProp = Object.defineProperty;
var __name = (target, value) => __defProp(target, "name", { value, configurable: true });
var HorizontalScrollBar = /* @__PURE__ */ __name(({
  container,
  autoHide = true,
  modifier,
  updateStyle,
  style,
  ...props
}) => {
  const scrollBarRef = useRef(null);
  const [scrollBarInstance] = useState(
    () => new HorizontalScrollBarInstance({
      container,
      scrollBar: scrollBarRef.current || void 0,
      modifier,
      autoHide,
      updateStyle
    })
  );
  useEffect(() => {
    scrollBarInstance.updateOptions({
      container,
      scrollBar: scrollBarRef.current || void 0,
      modifier,
      autoHide,
      updateStyle
    });
    return () => {
      scrollBarInstance.unmount();
    };
  }, [container, autoHide, modifier, updateStyle]);
  return /* @__PURE__ */ jsx("div", { ...props, ref: scrollBarRef });
}, "HorizontalScrollBar");
var VerticalScrollBar = /* @__PURE__ */ __name(({
  container,
  modifier,
  autoHide = true,
  updateStyle,
  style,
  ...props
}) => {
  const scrollBarRef = useRef(null);
  const [scrollBarInstance] = useState(
    () => new VerticalScrollBarInstance({
      container,
      scrollBar: scrollBarRef.current || void 0,
      modifier,
      autoHide,
      updateStyle
    })
  );
  useEffect(() => {
    scrollBarInstance.updateOptions({
      container,
      scrollBar: scrollBarRef.current || void 0,
      modifier,
      autoHide,
      updateStyle
    });
    return () => {
      scrollBarInstance.unmount();
    };
  }, [container, autoHide, modifier, updateStyle]);
  return /* @__PURE__ */ jsx("div", { ...props, ref: scrollBarRef });
}, "VerticalScrollBar");
var ScrollBar = /* @__PURE__ */ __name(({
  children,
  vertical = true,
  horizontal = true,
  ...props
}) => {
  const [container, setContainer] = useState();
  return /* @__PURE__ */ jsxs(
    "div",
    {
      ...props,
      ref: (el) => {
        if (container !== el) {
          setContainer(el || void 0);
        }
      },
      children: [
        children,
        horizontal ? /* @__PURE__ */ jsx(
          HorizontalScrollBar,
          {
            container,
            ...typeof horizontal === "object" ? horizontal : {}
          }
        ) : null,
        vertical ? /* @__PURE__ */ jsx(
          VerticalScrollBar,
          {
            container,
            ...typeof vertical === "object" ? vertical : {}
          }
        ) : null
      ]
    }
  );
}, "ScrollBar");

export { HorizontalScrollBar, ScrollBar, VerticalScrollBar };
